============
Installation
============

At the command line::

    $ easy_install deadgargoyle

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv deadgargoyle
    $ pip install deadgargoyle
